ghost_autocomplete library
Classes
- GhostAutocompleteController
- GhostAutocompleteListTextField
- A widget that shows a dropdown list of suggestions as the user types.
- GhostAutocompleteTextField
- A TextField that displays a "ghost" suggestion tail based on the user's input.
- GhostAutocompleteTextFormField
- GhostSpellCheckService
- A custom SpellCheckService that uses a user-defined list or callback to provide suggestions.
- GhostSpellCheckTextField
- A widget that combines inline ghost autocomplete with a custom spell check service.
Typedefs
-
GhostListSuggestionProvider
= FutureOr<
List< Function(String text)String> > - A callback that provides a list of suggestions based on the current text.
-
GhostSuggestionProvider
= FutureOr<
String?> Function(String text) - A callback that provides a suggestion based on the current text. Supports both synchronous (String?) and asynchronous (Future<String?>) results.
-
SpellCheckSuggestionsProvider
= FutureOr<
List< Function(String word)String> ?> - A callback that provides spell check suggestions for a given word.